/****************************************************************************
** Meta object code from reading C++ file 'kstartupinfo.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kwindowsystem-6.25.0/src/kstartupinfo.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kstartupinfo.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KStartupInfoE_t {};
} // unnamed namespace

template <> constexpr inline auto KStartupInfo::qt_create_metaobjectdata<qt_meta_tag_ZN12KStartupInfoE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KStartupInfo",
        "gotNewStartup",
        "",
        "KStartupInfoId",
        "id",
        "KStartupInfoData",
        "data",
        "gotStartupChange",
        "gotRemoveStartup",
        "startups_cleanup",
        "startups_cleanup_no_age",
        "got_message",
        "msg",
        "window_added",
        "WId",
        "w",
        "slot_window_added"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'gotNewStartup'
        QtMocHelpers::SignalData<void(const KStartupInfoId &, const KStartupInfoData &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'gotStartupChange'
        QtMocHelpers::SignalData<void(const KStartupInfoId &, const KStartupInfoData &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'gotRemoveStartup'
        QtMocHelpers::SignalData<void(const KStartupInfoId &, const KStartupInfoData &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'startups_cleanup'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'startups_cleanup_no_age'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'got_message'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'window_added'
        QtMocHelpers::SlotData<void(WId)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'slot_window_added'
        QtMocHelpers::SlotData<void(WId)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KStartupInfo, qt_meta_tag_ZN12KStartupInfoE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KStartupInfo::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KStartupInfoE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KStartupInfoE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KStartupInfoE_t>.metaTypes,
    nullptr
} };

void KStartupInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KStartupInfo *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->gotNewStartup((*reinterpret_cast<std::add_pointer_t<KStartupInfoId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KStartupInfoData>>(_a[2]))); break;
        case 1: _t->gotStartupChange((*reinterpret_cast<std::add_pointer_t<KStartupInfoId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KStartupInfoData>>(_a[2]))); break;
        case 2: _t->gotRemoveStartup((*reinterpret_cast<std::add_pointer_t<KStartupInfoId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KStartupInfoData>>(_a[2]))); break;
        case 3: _t->d->startups_cleanup(); break;
        case 4: _t->d->startups_cleanup_no_age(); break;
        case 5: _t->d->got_message((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->d->window_added((*reinterpret_cast<std::add_pointer_t<WId>>(_a[1]))); break;
        case 7: _t->d->slot_window_added((*reinterpret_cast<std::add_pointer_t<WId>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KStartupInfo::*)(const KStartupInfoId & , const KStartupInfoData & )>(_a, &KStartupInfo::gotNewStartup, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KStartupInfo::*)(const KStartupInfoId & , const KStartupInfoData & )>(_a, &KStartupInfo::gotStartupChange, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KStartupInfo::*)(const KStartupInfoId & , const KStartupInfoData & )>(_a, &KStartupInfo::gotRemoveStartup, 2))
            return;
    }
}

const QMetaObject *KStartupInfo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KStartupInfo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KStartupInfoE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KStartupInfo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void KStartupInfo::gotNewStartup(const KStartupInfoId & _t1, const KStartupInfoData & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KStartupInfo::gotStartupChange(const KStartupInfoId & _t1, const KStartupInfoData & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KStartupInfo::gotRemoveStartup(const KStartupInfoId & _t1, const KStartupInfoData & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}
QT_WARNING_POP
